1. run `zkdir` to start a http server, the default port is 8000
2. run `zkdir -port=9000` to use a custom port
命令行模式：
kk
参数:
    -port=8000  端口号，默认端口为8000
    -dev=False  开发者模式，默认为False
    -all=False  是否显示隐藏文件，默认为True


3. click "切换显示" to change display image/video/audio
4. add url parameter w=256 or h=256 to scale image
